"""
Main CLI entrypoint.
"""
import sys


def print_info() -> None:
    """
    Print package info to stdout.
    """
    print(
        "Type annotations for aiobotocore.finspace 2.2.0\nVersion:         2.2.0\nBuilder version:"
        " 7.4.0\nDocs:           "
        " https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_finspace//\nBoto3 docs: "
        "     https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace.html#finspace\nOther"
        " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
        " https://github.com/vemel/mypy_boto3_builder/releases"
    )


def print_version() -> None:
    """
    Print package version to stdout.
    """
    print("2.2.0")


def main() -> None:
    """
    Main CLI entrypoint.
    """
    if "--version" in sys.argv:
        return print_version()
    print_info()


if __name__ == "__main__":
    main()



"""
Main interface for finspace service.

Usage::

    ```python
    from aiobotocore.session import get_session
    from types_aiobotocore_finspace import (
        Client,
        finspaceClient,
    )

    session = get_session()
    async with session.create_client("finspace") as client:
        client: finspaceClient
        ...

    ```
"""
from .client import finspaceClient

Client = finspaceClient

__all__ = ("Client", "finspaceClient")
